function H= scalpmap(mnt, w)
%SCALPMAP - Display a vector as scalp topography
%
%Synopsis:
% H= scalpmap(MNT, W)
%
%Arguments:
% MNT: An electrode montage, see getElectrodePositions
% W:   Vector to be displayed as scalp topography. The length of W must
%      concide with the length of MNT.clab
%
%Returns:
% H:   Handle to graphical objects

%% Draw head outline
LineSpec= {'k', 'LineWidth',2};
T= linspace(0, 2*pi, 360);
H.outline= plot(cos(T), sin(T), LineSpec{:});
hold on
nose= [1 1.1 1];
nosi= [86 90 94]+1;
H.nose= plot(nose.*cos(T(nosi)), nose.*sin(T(nosi)), LineSpec{:});

%% Plot interpolated values
xx= linspace(min(mnt.x), max(mnt.x), 50);
yy= linspace(min(mnt.y), max(mnt.y), 50)';
[xg,yg,zg]= griddata(mnt.x, mnt.y, w, xx, yy, 'linear');
H.patch= pcolor(xg, yg, zg);
shading interp
axis equal off

%% Make range of colorbar symmetric
mm= max(abs(w));
set(gca, 'CLim',[-mm mm]);
H.cb= colorbar;
hold off
